#ifndef _OF_APP_RUNNER
#define _OF_APP_RUNNER


#include "ofConstants.h"
#include "ofSimpleApp.h"
#include "ofGraphics.h"
#include "ofMath.h"
#include "ofUtils.h"

void 		ofSetupOpenGL(int w, int h, int screenMode);			// sets up the opengl context!
void 		ofRunApp(ofSimpleApp * OFSA);
float 		ofGetFrameRate();
void 		ofSetFrameRate(int targetRate);
void 		ofHideCursor();
void 		ofShowCursor();
void 		ofSetVerticalSync(bool bSync);

#endif	
